@@ -6,16 +6,16 @@ Geo::Coder::List - Provide lots of backends for HTML::GoogleMaps::V3
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
 L<Geo::Coder::All> and L<Geo::Coder::Many> are great routines but neither quite does what I want.
-This module's primary use is to all many backends to be used by L<HTML::GoogleMaps::V3>
+This module's primary use is to allow many backends to be used by L<HTML::GoogleMaps::V3>
 
 =head1 SUBROUTINES/METHODS
 
@@ -72,10 +72,16 @@ sub geocode {
 		$params{'location'} = shift;
 	}
 
-	if(!defined($params{'location'})) {
+	my $location = $params{'location'};
+
+	if(!defined($location)) {
 		return;
 	}
 
+	if((!wantarray) && (my $rc = $locations{$location})) {
+		return $rc;
+	}
+
 	foreach my $geocoder(@{$self->{geocoders}}) {
 		my @rc;
 		eval {
@@ -103,8 +109,13 @@ sub geocode {
 
 			}
 		}
+
 		if(scalar(@rc)) {
-			return wantarray ? @rc : $rc[0];
+			if(wantarray) {
+				return @rc;
+			}
+			$locations{$location} = $rc[0];
+			return $rc[0];
 		}
 	}
 }
@@ -160,7 +171,7 @@ L<http://search.cpan.org/dist/Geo-Coder-List/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2016 Nigel Horne.
+Copyright 2016-2017 Nigel Horne.
 
 This program is released under the following licence: GPL
 
